summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/replication_coordinator_external_state.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/repl/replication_coordinator_external_state.h')
-rw-r--r--src/mongo/db/repl/replication_coordinator_external_state.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/repl/replication_coordinator_external_state.h b/src/mongo/db/repl/replication_coordinator_external_state.h
index e5ca3cfe12c..29cc6dd9c5b 100644
--- a/src/mongo/db/repl/replication_coordinator_external_state.h
+++ b/src/mongo/db/repl/replication_coordinator_external_state.h
@@ -260,11 +260,11 @@ public:
virtual void updateCommittedSnapshot(const OpTime& newCommitPoint) = 0;
/**
* Updates the local snapshot to a consistent point for secondary reads.
*
- * It is illegal to call with a optime that does not name an existing snapshot.
+ * It is illegal to call with a non-existent optime.
*/
- virtual void updateLocalSnapshot(const OpTime& optime) = 0;
+ virtual void updateLastAppliedSnapshot(const OpTime& optime) = 0;
/**
* Returns whether or not the SnapshotThread is active.
@@ -260,11 +260,11 @@ public:
virtual void updateCommittedSnapshot(const OpTime& newCommitPoint) = 0;
/**
- * Updates the local snapshot to a consistent point for secondary reads.
+ * Updates the lastApplied snapshot to a consistent point for secondary reads.
*